summaryrefslogtreecommitdiffstats
path: root/krita/core/kis_histogram.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /krita/core/kis_histogram.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'krita/core/kis_histogram.h')
-rw-r--r--krita/core/kis_histogram.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/krita/core/kis_histogram.h b/krita/core/kis_histogram.h
index 3365bde1..3d315994 100644
--- a/krita/core/kis_histogram.h
+++ b/krita/core/kis_histogram.h
@@ -51,7 +51,7 @@ public:
double m_max, m_min, m_mean, m_total, m_median, m_stddev;
- Q_UINT32 m_high, m_low, m_count;
+ TQ_UINT32 m_high, m_low, m_count;
friend class KisHistogram;
@@ -70,18 +70,18 @@ public:
*/
inline double getMin() { return m_min; }
/// This function return the highest value of the histogram
- inline Q_UINT32 getHighest() { return m_high; }
+ inline TQ_UINT32 getHighest() { return m_high; }
/// This function return the lowest value of the histogram
- inline Q_UINT32 getLowest() { return m_low; }
+ inline TQ_UINT32 getLowest() { return m_low; }
/// This function return the mean of value of the histogram
inline double getMean() { return m_mean; }
//double getMedian() { return m_median; }
//double getStandardDeviation() { return m_stddev; }
/// This function return the number of pixels used by the histogram
- inline Q_UINT32 getCount() { return m_count; }
+ inline TQ_UINT32 getCount() { return m_count; }
/** The sum of (the contents of every bin * the double value of that bin)*/
inline double getTotal() { return m_total; }
//Q_UINT8 getPercentile() { return m_percentile; } // What is this exactly? XXX
};
KisHistogram(KisPaintLayerSP layer,
@@ -108,14 +108,14 @@ public:
/** The information on the current selection for the current channel */
Calculations selectionCalculations();
- inline Q_UINT32 getValue(Q_UINT8 i) { return m_producer->getBinAt(m_channel, i); }
+ inline TQ_UINT32 getValue(TQ_UINT8 i) { return m_producer->getBinAt(m_channel, i); }
inline enumHistogramType getHistogramType() { return m_type; }
inline void setHistogramType(enumHistogramType type) { m_type = type; }
inline void setProducer(KisHistogramProducerSP producer) { m_producer = producer; }
- inline void setChannel(Q_INT32 channel) { m_channel = channel; }
+ inline void setChannel(TQ_INT32 channel) { m_channel = channel; }
inline KisHistogramProducerSP producer() { return m_producer; }
- inline Q_INT32 channel() { return m_channel; }
+ inline TQ_INT32 channel() { return m_channel; }
inline bool hasSelection() { return m_selection; }
inline double selectionFrom() { return m_selFrom; }
@@ -129,7 +129,7 @@ public:
private:
// Dump the histogram to debug.
void dump();
- QValueVector<Calculations> calculateForRange(double from, double to);
+ TQValueVector<Calculations> calculateForRange(double from, double to);
Calculations calculateSingleRange(int channel, double from, double to);
KisPaintDeviceSP m_device;
@@ -137,13 +137,13 @@ private:
enumHistogramType m_type;
- Q_INT32 m_channel;
+ TQ_INT32 m_channel;
double m_selFrom, m_selTo;
bool m_selection;
KisPaintDeviceSP m_dev;
- QValueVector<Calculations> m_completeCalculations, m_selectionCalculations;
+ TQValueVector<Calculations> m_completeCalculations, m_selectionCalculations;
};
@@ -70,18 +70,18 @@ public:
/** The sum of (the contents of every bin * the double value of that bin)*/
inline double getTotal() { return m_total; }
- //Q_UINT8 getPercentile() { return m_percentile; } // What is this exactly? XXX
+ //TQ_UINT8 getPercentile() { return m_percentile; } // What is this exactly? XXX
};
KisHistogram(KisPaintLayerSP layer,